/*
 * Copyright (c) 2002-2006 Samit Basu
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
#ifndef __helpgen_hpp__
#define __helpgen_hpp__

#include <QWidget>
#include <string>
#include "Array.hpp"
#include "FunctionDef.hpp"

using namespace std;

class ConsoleWidget : public QWidget {
  Q_OBJECT
private slots:
  void LaunchHelpWindow();
  void exitNow();
  void Run();
public:
  ConsoleWidget();
  virtual ~ConsoleWidget() {};
};

class Interpreter;

class HelpHandler : public QObject {
  Q_OBJECT
  Interpreter *m_interp;  
  string m_text;
  QStringList m_cmds;
public:
  HelpHandler(Interpreter *interp, QStringList cmds);
  string text() {return m_text;
  }
public slots:
  void AddOutputString(string);
  void SetPrompt(string);
  void DoGraphicsCall(FuncPtr f, ArrayVector m, int narg);
};

void DoHelpGen(QString src, QString dst);

#endif
